

#!/usr/bin/python3
# coding=utf-8
###################################################################
#           ____     _     _ __  __                 
#          / __/__  (_)___(_) /_/ /  ___  ___  ___ _
#         _\ \/ _ \/ / __/ / __/ /__/ _ \/ _ \/ _ `/
#        /___/ .__/_/_/ /_/\__/____/\___/_//_/\_, / 
#           /_/                              /___/  
# Copyright (c) 2024 Chongqing Spiritlong Technology Co., Ltd.
# All rights reserved.  
# @author	arthuryang
# @brief	word工具集
#
###################################################################  

from	SpiritLong_word.word	import	open_docx,					\
					save_doc,					\
					save_docx,					\
					delete_paragraph,				\
					add_paragraphs,					\
					new_paragraph_data,				\
					new_run_data,					\
					add_blank_paragraphs,				\
					add_text_with_style,				\
					replace_text,					\
					append_text,					\
					find_paragraph,					\
					get_styles,					\
					table_remove_row,				\
					table_insert_row,				\
					set_cell_border,				\
					table_cell_fill,				\
					create_table,					\
					merge_cell,					\
					set_table_column_width_and_vertical_center